@@ -9,3 +9,7 @@ class ImagesGateway(metaclass=ABCMeta):
     @abstractmethod
     def get_base_image(self, image_to_scan) -> str:
         "get base image"
+
+    @abstractmethod
+    def validate_base_image_date(self, image_to_scan, referenced_date) -> str:
+        "validate base image date"
\ No newline at end of file
